@@ -1,6 +1,7 @@
 from pkg_resources import DistributionNotFound, get_distribution
 
 from . import (
+    bias_removal,
     bootstrap,
     comparisons,
     constants,
@@ -11,9 +12,11 @@ from . import (
     relative_entropy,
     smoothing,
     stats,
+    testing,
     tutorial,
 )
 from .classes import HindcastEnsemble, PerfectModelEnsemble
+from .preprocessing import mpi, shared
 from .versioning.print_versions import show_versions
 
 try:
