@@ -4,6 +4,21 @@ class Error(Exception):
     pass
 
 
+class CoordinateError(Error):
+    """Exception raised when the input xarray object doesn't have the
+    appropriate coordinates."""
+
+    def __init__(self, message):
+        self.message = message
+
+
+class DatasetError(Error):
+    """Exception raised when there is any issues related to a dataset."""
+
+    def __init__(self, message):
+        self.message = message
+
+
 class DimensionError(Error):
     """Exception raised when the input xarray object doesn't have the
     appropriate dimensions."""
@@ -12,9 +27,9 @@ class DimensionError(Error):
         self.message = message
 
 
-class CoordinateError(Error):
-    """Exception raised when the input xarray object doesn't have the
-    appropriate coordinates."""
+class KeywordError(Error):
+    """Exception raised when the keyword used in the function is not appropriate or
+    does not work in the given case."""
 
     def __init__(self, message):
         self.message = message
@@ -26,10 +41,3 @@ class VariableError(Error):
 
     def __init__(self, message):
         self.message = message
-
-
-class DatasetError(Error):
-    """Exception raised when there is any issues related to a dataset."""
-
-    def __init__(self, message):
-        self.message = message
